#!/bio/bash

set -e
set -x

drupal9_path=/var/drupal/d9
drupal10_path=/var/drupal/d10

function drupal_setup_common() {
  composer config --no-plugins allow-plugins.wikimedia/composer-merge-plugin true
  composer require wikimedia/composer-merge-plugin
  composer config extra.merge-plugin --merge --json '{"include": ["web/modules/contrib/chosen/composer.libraries.json"]}'
  composer config --no-plugins allow-plugins.oomphinc/composer-installers-extender true
  composer require oomphinc/composer-installers-extender
  composer require drush/drush drupal/admin_toolbar drupal/devel
  composer upgrade -W
  mkdir -p drush
  mkdir -p web/modules/custom
  ln -s /var/www/html web/modules/custom/notify_bar
  ln -fs /var/www/html/.ddev/drupal/settings.dev.php web/sites/default
}

function drupal_init_common() {
  if ! drush status --field=bootstrap | grep -q Successful; then
    drush site:install --account-name=admin --account-pass=admin -y
  fi
  drush en -y admin_toolbar_tools admin_toolbar_search devel
}

composer global config --no-plugins allow-plugins.dealerdirect/phpcodesniffer-composer-installer true
composer global require drupal/coder

mysql -uroot -proot -e "SET GLOBAL TRANSACTION ISOLATION LEVEL READ COMMITTED;"
mysql -uroot -proot -e 'CREATE DATABASE IF NOT EXISTS drupal9' mysql
mysql -uroot -proot -e 'CREATE DATABASE IF NOT EXISTS drupal10' mysql
mysql -uroot -proot -e "GRANT ALL ON drupal9.* to 'db'@'%' IDENTIFIED BY 'db';" mysql
mysql -uroot -proot -e "GRANT ALL ON drupal10.* to 'db'@'%' IDENTIFIED BY 'db';" mysql

sudo chown $(id -u):$(id -g) /var/drupal

if [[ ! -d $drupal9_path ]]; then
  composer create "drupal/recommended-project:^9" $drupal9_path
  cd $drupal9_path
  drupal_setup_common
else
  cd $drupal9_path
  composer upgrade -W
fi

if [[ ! -d $drupal10_path ]]; then
  composer create "drupal/recommended-project:^10" $drupal10_path
  cd $drupal10_path
  drupal_setup_common
else
  cd $drupal10_path
  composer upgrade -W
fi

cd /var/www/html
cp .ddev/drupal/settings9.php /var/drupal/d9/web/sites/default/settings.php
cp .ddev/drupal/settings9.ddev.php /var/drupal/d9/web/sites/default/settings.ddev.php
cp .ddev/drupal/settings10.php /var/drupal/d10/web/sites/default/settings.php
cp .ddev/drupal/settings10.ddev.php /var/drupal/d10/web/sites/default/settings.ddev.php

cd $drupal9_path
echo -e "options:\n  uri: '${DDEV_PRIMARY_URL/notifybar/d9.notifybar}'" > drush/drush.yml
drupal_init_common
# On d9, we use seven, on d10 we'll use claro, which is the default
drush then -y seven
drush cset -y system.theme admin seven
drush cr
drush updb -y

cd $drupal10_path
echo -e "options:\n  uri: '${DDEV_PRIMARY_URL/notifybar/d10.notifybar}'" > drush/drush.yml
drupal_init_common
drush cr
drush updb -y

cd $drupal9_path
drush en -y notify_bar || true
drush uli
cd $drupal10_path
drush en -y notify_bar || true
drush uli
