<?php

namespace Drupal\notify_bar;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Notify bar services.
 */
class NotifyBarInfo {
  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * NotifyBarInfo constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Returns the config.
   */
  public function getConfig($editable = FALSE) {
    if ($editable) {
      $config = $this->configFactory->getEditable('notify_bar.settings');
    }
    else {
      $config = $this->configFactory->get('notify_bar.settings');
    }
    if ($config != "") {
      return $config;
    }
  }

  public function isWithinDateRange($start_date = NULL, $end_date = NULL) {
    if (is_null($start_date) && is_null($end_date)) {
      $config = $this->getConfig();
      $start_date = $config->get("start_date");
      $end_date = $config->get("end_date");
    }
    if (empty($start_date) || empty($end_date)) {
      return FALSE;
    }
    $current_timestamp = \Drupal::time()->getRequestTime();
    $start_time = new DrupalDateTime($start_date);
    $start_time->modify('today');
    $start_timestamp = $start_time->getTimestamp();
    $end_time = new DrupalDateTime($end_date);
    $end_time->modify('tomorrow');
    $end_timestamp = $end_time->getTimestamp() - 1;
    return $start_timestamp <= $current_timestamp && $end_timestamp >= $current_timestamp;
  }
}
