<?php

namespace Drupal\notify_bar\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\notify_bar\NotifyBarInfo;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Render\RendererInterface;

/**
 * Notify bar block.
 *
 * @Block(
 *   id = "notify_bar_info",
 *   admin_label = @Translation("Notify Bar")
 * )
 */
class NotifyBarBlock extends BlockBase implements ContainerFactoryPluginInterface {
  /**
   * Notify bar info.
   *
   * @var \Drupal\notify_bar\NotifyBarInfo
   */
  protected $notifyInfo;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Construct.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param string $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\notify_bar\NotifyBarInfo $notifyInfo
   *   The notifyInfo service.
   */
  public function __construct(array $configuration,
    $plugin_id,
    $plugin_definition,
    NotifyBarInfo $notifyInfo,
    RendererInterface $renderer) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->notifyInfo = $notifyInfo;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
    $configuration,
    $plugin_id,
    $plugin_definition,
    $container->get('notify_bar.info'),
    $container->get('renderer'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->notifyInfo->getConfig();
    if (!empty($config)) {
      $message = $config->get("description.value");
      $btn_text = $config->get("notify_cta_text");
      $btn_url = $config->get("notify_cta_url");
      $background = $config->get("background");
      $color = $config->get("color");
      $build = [
        '#theme' => 'notify_bar_info',
        '#attached' => ['library' => ['notify_bar/notify-bar-layout']],
        '#message' => $message,
        '#btnText' => $btn_text,
        '#btnUrl' => $btn_url,
        '#background' => $background,
        '#color' => $color,
      ];
      $this->renderer->addCacheableDependency($build, $config);
      return $build;
    }
    else {
      return [
        '#markup' => $this->t('Configuration data missing....'),
      ];
    }
  }

  /**
   * Overrides \Drupal\block\BlockBase::access().
   */
  public function access(AccountInterface $account, $return_as_object = FALSE) {
    $config = $this->notifyInfo->getConfig();
    $access = parent::access($account, TRUE)->addCacheableDependency($config);
    if ($config->get('enable_date')) {
      if (!$this->notifyInfo->isWithinDateRange()) {
        $access = $access->forbidden()->addCacheableDependency($config);
      }
    }

    return $access;
  }
}
